"""Google OAuth re-exports for belgie consumers."""

_OAUTH_CLIENT_IMPORT_ERROR = (
    "belgie.oauth.google requires the 'oauth-client' extra. Install with: uv add belgie[oauth-client]"
)

try:
    from belgie_oauth import (  # type: ignore[import-not-found]
        GoogleOAuth,
        GoogleOAuthClient,
        GoogleOAuthPlugin,
        GoogleUserInfo,
    )
except ModuleNotFoundError as exc:
    raise ImportError(_OAUTH_CLIENT_IMPORT_ERROR) from exc

__all__ = [
    "GoogleOAuth",
    "GoogleOAuthClient",
    "GoogleOAuthPlugin",
    "GoogleUserInfo",
]



"""Organization alchemy adapter re-exports for belgie consumers."""

_ALCHEMY_IMPORT_ERROR = (
    "belgie.alchemy.organization requires the 'alchemy' and 'organization' extras. "
    "Install with: uv add belgie[alchemy,organization]"
)

try:
    from belgie_alchemy.organization import OrganizationAdapter
except ModuleNotFoundError as exc:
    raise ImportError(_ALCHEMY_IMPORT_ERROR) from exc

__all__ = ["OrganizationAdapter"]



"""Team protocol re-exports for belgie consumers."""

_PROTO_IMPORT_ERROR = "belgie.proto.team requires belgie-proto and the team types. Install with: uv add belgie-proto"

try:
    from belgie_proto.team import TeamAdapterProtocol, TeamMemberProtocol, TeamProtocol, TeamSessionProtocol
except ModuleNotFoundError as exc:
    raise ImportError(_PROTO_IMPORT_ERROR) from exc

__all__ = [
    "TeamAdapterProtocol",
    "TeamMemberProtocol",
    "TeamProtocol",
    "TeamSessionProtocol",
]



"""Organization protocol re-exports for belgie consumers."""

_PROTO_IMPORT_ERROR = (
    "belgie.proto.organization requires belgie-proto and the organization types. Install with: uv add belgie-proto"
)

try:
    from belgie_proto.organization import (
        InvitationProtocol,
        MemberProtocol,
        OrganizationAdapterProtocol,
        OrganizationProtocol,
        OrganizationSessionProtocol,
    )
except ModuleNotFoundError as exc:
    raise ImportError(_PROTO_IMPORT_ERROR) from exc

__all__ = [
    "InvitationProtocol",
    "MemberProtocol",
    "OrganizationAdapterProtocol",
    "OrganizationProtocol",
    "OrganizationSessionProtocol",
]



"""Team re-exports for belgie consumers."""

_TEAM_IMPORT_ERROR = "belgie.team requires the 'team' extra. Install with: uv add belgie[team]"

try:
    from belgie_team import (  # type: ignore[import-not-found]
        Team,
        TeamClient,
        TeamMemberView,
        TeamPlugin,
        TeamView,
    )
except ModuleNotFoundError as exc:
    raise ImportError(_TEAM_IMPORT_ERROR) from exc

__all__ = [
    "Team",
    "TeamClient",
    "TeamMemberView",
    "TeamPlugin",
    "TeamView",
]



"""OAuth server re-exports for belgie consumers."""

_OAUTH_IMPORT_ERROR = "belgie.oauth.server requires the 'oauth' extra. Install with: uv add belgie[oauth]"

try:
    from belgie_oauth_server import (  # type: ignore[import-not-found]
        OAuthLoginContext,
        OAuthLoginIntent,
        OAuthResource,
        OAuthServer,
        OAuthServerClient,
        OAuthServerPlugin,
        build_oauth_metadata,
        build_oauth_metadata_well_known_path,
        build_protected_resource_metadata,
        build_protected_resource_metadata_well_known_path,
    )
except ModuleNotFoundError as exc:
    raise ImportError(_OAUTH_IMPORT_ERROR) from exc

__all__ = [
    "OAuthLoginContext",
    "OAuthLoginIntent",
    "OAuthResource",
    "OAuthServer",
    "OAuthServerClient",
    "OAuthServerPlugin",
    "build_oauth_metadata",
    "build_oauth_metadata_well_known_path",
    "build_protected_resource_metadata",
    "build_protected_resource_metadata_well_known_path",
]



"""Organization re-exports for belgie consumers."""

_ORG_IMPORT_ERROR = "belgie.organization requires the 'organization' extra. Install with: uv add belgie[organization]"

try:
    from belgie_organization import (  # type: ignore[import-not-found]
        InvitationView,
        MemberView,
        Organization,
        OrganizationClient,
        OrganizationFullView,
        OrganizationPlugin,
        OrganizationView,
        RoleValue,
        has_any_role,
        has_role,
        normalize_roles,
        parse_roles,
    )
except ModuleNotFoundError as exc:
    raise ImportError(_ORG_IMPORT_ERROR) from exc

__all__ = [
    "InvitationView",
    "MemberView",
    "Organization",
    "OrganizationClient",
    "OrganizationFullView",
    "OrganizationPlugin",
    "OrganizationView",
    "RoleValue",
    "has_any_role",
    "has_role",
    "normalize_roles",
    "parse_roles",
]
